@@ -22,6 +22,7 @@ from mock import Mock
 from requests.exceptions import HTTPError
 from webtest.app import TestApp
 
+from conan.api.subapi.audit import CONAN_CENTER_AUDIT_PROVIDER_NAME, _save_providers
 from conan.api.subapi.config import ConfigAPI
 from conan.api.subapi.remotes import _save
 from conan.cli.exit_codes import SUCCESS
@@ -42,7 +43,7 @@ from conan.test.utils.mocks import RedirectedTestOutput
 from conan.test.utils.scm import create_local_git_repo
 from conan.test.utils.server_launcher import (TestServerLauncher)
 from conan.test.utils.test_files import temp_folder
-from conans.util.files import mkdir, save_files, save, load
+from conan.internal.util.files import mkdir, save_files, save, load
 
 NO_SETTINGS_PACKAGE_ID = "da39a3ee5e6b4b0d3255bfef95601890afd80709"
 
@@ -418,6 +419,8 @@ class TestClient:
         self.servers = servers or {}
         if servers is not False:  # Do not mess with registry remotes
             self.update_servers()
+
+        self.update_providers()
         self.current_folder = current_folder or temp_folder(path_with_spaces)
 
         # Once the client is ready, modify the configuration
@@ -477,6 +480,16 @@ class TestClient:
                 remotes.append(Remote(name, server))
         _save(HomePaths(self.cache_folder).remotes_path, remotes)
 
+
+    def update_providers(self):
+        default_providers = {
+            CONAN_CENTER_AUDIT_PROVIDER_NAME: {
+                "url": "https://fakeurl/",
+                "type": "conan-center-proxy"
+            }
+        }
+        _save_providers(HomePaths(self.cache_folder).providers_path, default_providers)
+
     @contextmanager
     def chdir(self, newdir):
         old_dir = self.current_folder
@@ -492,7 +505,7 @@ class TestClient:
     @contextmanager
     def mocked_servers(self, requester=None):
         _req = requester or TestRequester(self.servers)
-        with mock.patch("conans.client.rest.conan_requester.requests", _req):
+        with mock.patch("conan.internal.rest.conan_requester.requests", _req):
             yield
 
     @contextmanager
@@ -578,7 +591,7 @@ class TestClient:
         self.stderr = RedirectedTestOutput()
         try:
             with redirect_output(self.stderr, self.stdout):
-                from conans.util.runners import conan_run
+                from conan.internal.util.runners import conan_run
                 ret = conan_run(command, cwd=cwd or self.current_folder)
         finally:
             self.stdout = str(self.stdout)
@@ -687,6 +700,8 @@ class TestClient:
 
     def get_latest_ref_layout(self, ref) -> RecipeLayout:
         """Get the latest RecipeLayout given a file reference"""
+        if not ref.revision:
+            ref = self.cache.get_latest_recipe_reference(ref)
         ref_layout = self.cache.recipe_layout(ref)
         return ref_layout
 
