@@ -10,13 +10,13 @@ from mock import patch
 
 from conan.api.model import Remote
 from conan.internal.api.config.config_installer import _hide_password
-from conans.client.downloaders.file_downloader import FileDownloader
+from conan.internal.rest.file_downloader import FileDownloader
 from conan.internal.paths import DEFAULT_CONAN_HOME
 from conan.test.assets.genconanfile import GenConanfile
 from conan.test.utils.file_server import TestFileServer
 from conan.test.utils.test_files import scan_folder, temp_folder, tgz_with_contents
 from conan.test.utils.tools import TestClient, zipdir
-from conans.util.files import load, mkdir, save, save_files
+from conan.internal.util.files import load, mkdir, save, save_files
 
 
 def make_file_read_only(file_path):
