@@ -14,7 +14,7 @@ from conan.errors import ConanException
 from conan.test.utils.file_server import TestFileServer
 from conan.test.utils.test_files import temp_folder
 from conan.test.utils.tools import TestClient
-from conans.util.files import save, load, rmdir, mkdir, remove
+from conan.internal.util.files import save, load, rmdir, mkdir, remove
 
 
 class TestDownloadCacheBackupSources:
@@ -23,7 +23,7 @@ class TestDownloadCacheBackupSources:
             assert not url.startswith("http://myback")
             save(filepath, f"Hello, world!")
 
-        with mock.patch("conans.client.downloaders.file_downloader.FileDownloader.download",
+        with mock.patch("conan.internal.rest.file_downloader.FileDownloader.download",
                         custom_download):
             client = TestClient(default_server_user=True, light=True)
             tmp_folder = temp_folder()
@@ -203,6 +203,44 @@ class TestDownloadCacheBackupSources:
         assert f"Sources for {self.file_server.fake_url}/internet/myfile.txt found in remote backup" in self.client.out
         assert f"File {self.file_server.fake_url}/mycompanystorage/mycompanyfile.txt not found in {self.file_server.fake_url}/backups/" in self.client.out
 
+    def test_unknown_handling(self):
+        http_server_base_folder_internet = os.path.join(self.file_server.store, "internet")
+
+        save(os.path.join(http_server_base_folder_internet, "myfile.txt"), "Hello, world!")
+
+        sha256 = "315f5bdb76d078c43b8ac0064e4a0164612b1fce77c869345bfc94c75894edd3"
+        conanfile = textwrap.dedent(f"""
+                            from conan import ConanFile
+                            from conan.tools.files import download
+                            class Pkg2(ConanFile):
+                                name = "pkg"
+                                version = "1.0"
+                                def source(self):
+                                    download(self, "{self.file_server.fake_url}/internet/myfile.txt", "myfile.txt",
+                                             sha256="{sha256}")
+                            """)
+
+        self.client.save_home(
+            {"global.conf": f"core.sources:download_cache={self.download_cache_folder}\n"
+                            f"core.sources:download_urls=['origin']\n"
+                            f"core.sources:upload_url={self.file_server.fake_url}/backups/"})
+
+        self.client.save({"conanfile.py": conanfile})
+        self.client.run("source .")
+        json_path = os.path.join(self.download_cache_folder, "s", sha256 + ".json")
+        contents = json.loads(load(json_path))
+        assert "unknown" in contents["references"]
+
+        s_folder = os.path.join(self.download_cache_folder, "s")
+        assert len(os.listdir(s_folder)) == 2
+
+        self.client.run("export .")
+        self.client.run("upload * -c -r=default")
+        assert "No backup sources files to upload" in self.client.out
+
+        self.client.run("cache clean --backup-sources")
+        assert len(os.listdir(s_folder)) == 0
+
     def test_download_origin_first(self):
         http_server_base_folder_internet = os.path.join(self.file_server.store, "internet")
 
@@ -476,7 +514,7 @@ class TestDownloadCacheBackupSources:
         def custom_download(this, url, *args, **kwargs):
             raise NotFoundException()
 
-        with mock.patch("conans.client.downloaders.file_downloader.FileDownloader.download",
+        with mock.patch("conan.internal.rest.file_downloader.FileDownloader.download",
                         custom_download):
             client = TestClient(default_server_user=True, light=True)
             download_cache_folder = temp_folder()
@@ -791,7 +829,7 @@ class TestDownloadCacheBackupSources:
 
         self.client.save({"conanfile.py": conanfile})
 
-        with mock.patch("conans.client.downloaders.file_downloader.FileDownloader._download_file",
+        with mock.patch("conan.internal.rest.file_downloader.FileDownloader._download_file",
                         custom_download):
             self.client.run("source .", assert_error=True)
             # The mock does not actually download a file, let's add it for the test
@@ -833,7 +871,7 @@ class TestDownloadCacheBackupSources:
                             f"core.sources:upload_url={self.file_server.fake_url}/backup/"})
 
         self.client.save({"conanfile.py": conanfile})
-        with mock.patch("conans.client.downloaders.file_downloader.FileDownloader._download_file",
+        with mock.patch("conan.internal.rest.file_downloader.FileDownloader._download_file",
                         custom_download):
             self.client.run("source .", assert_error=True)
 
