@@ -5,7 +5,7 @@ import textwrap
 
 from conan.api.model import RecipeReference
 from conan.test.utils.tools import TestClient, NO_SETTINGS_PACKAGE_ID, GenConanfile
-from conans.util.files import load
+from conan.internal.util.files import load
 
 
 def test_dependencies_order_matches_requires():
@@ -160,7 +160,7 @@ def test_create_package_requires():
     client.save({"conanfile.py": conanfile,
                  "test_package/conanfile.py": test_conanfile})
 
-    client.run("create . --name=pkg --version=0.1 --user=lasote --channel=testing")
+    client.run("create . --name=pkg --version=0.1 --user=lasote --channel=testing -vv")
 
     assert "pkg/0.1@lasote/testing (test package): build() " \
            "Requires: other/1.0@user/channel" in client.out
@@ -170,6 +170,10 @@ def test_create_package_requires():
     assert "pkg/0.1@lasote/testing (test package): build() cpp_info dep: dep" in client.out
     assert "pkg/0.1@lasote/testing (test package): build() cpp_info dep: pkg" in client.out
 
+    # Check that the additional info shows up when creating pkg
+    # Graph info, package creation, and test package graph info
+    assert client.out.count("requires: dep/0.1@user/channel") == 3
+
 
 def test_package_folder_build_error():
     """
