@@ -3,18 +3,17 @@ import os
 import platform
 import re
 import textwrap
-import unittest
 
 import pytest
 
 from conan.cli.exit_codes import ERROR_INVALID_CONFIGURATION, ERROR_GENERAL
-from conans.client.graph.graph import BINARY_INVALID
+from conan.internal.graph.graph import BINARY_INVALID
 from conan.test.assets.genconanfile import GenConanfile
-from conans.util.files import save, load
+from conan.internal.util.files import save, load
 from conan.test.utils.tools import TestClient, NO_SETTINGS_PACKAGE_ID
 
 
-class TestValidate(unittest.TestCase):
+class TestValidate:
 
     def test_validate_create(self):
         client = TestClient()
@@ -32,20 +31,19 @@ class TestValidate(unittest.TestCase):
         client.save({"conanfile.py": conanfile})
 
         client.run("create . --name=pkg --version=0.1 -s os=Linux")
-        self.assertIn("pkg/0.1: Package '9a4eb3c8701508aa9458b1a73d0633783ecc2270' created",
-                      client.out)
+        assert "pkg/0.1: Package '9a4eb3c8701508aa9458b1a73d0633783ecc2270' created" in client.out
 
         error = client.run("create . --name=pkg --version=0.1 -s os=Windows", assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg/0.1: Invalid: Windows not supported", client.out)
+        assert error == ERROR_INVALID_CONFIGURATION
+        assert "pkg/0.1: Invalid: Windows not supported"in client.out
 
         client.run("graph info --require pkg/0.1 -s os=Windows")
-        self.assertIn("binary: Invalid", client.out)
+        assert "binary: Invalid"in client.out
         assert "info_invalid: Windows not supported" in client.out
 
         client.run("graph info --require pkg/0.1 -s os=Windows --format json")
         myjson = json.loads(client.stdout)
-        self.assertEqual(myjson["graph"]["nodes"]["1"]["binary"], BINARY_INVALID)
+        assert myjson["graph"]["nodes"]["1"]["binary"] == BINARY_INVALID
         assert myjson["graph"]["nodes"]["1"]["info_invalid"] == "Windows not supported" in client.out
 
     def test_validate_header_only(self):
@@ -125,38 +123,35 @@ class TestValidate(unittest.TestCase):
         client.run("create . --name=pkg --version=0.1 -s os=Linux")
         package_id = "9a4eb3c8701508aa9458b1a73d0633783ecc2270"
         missing_id = "ebec3dc6d7f6b907b3ada0c3d3cdc83613a2b715"
-        self.assertIn(f"pkg/0.1: Package '{package_id}' created",
-                      client.out)
+        assert f"pkg/0.1: Package '{package_id}' created" in client.out
 
         # This is the main difference, building from source for the specified conf, fails
         client.run("create . --name=pkg --version=0.1 -s os=Windows", assert_error=True)
-        self.assertIn("pkg/0.1: Cannot build for this configuration: Windows not supported",
-                      client.out)
+        assert "pkg/0.1: Cannot build for this configuration: Windows not supported" in client.out
         client.assert_listed_binary({"pkg/0.1": (missing_id, "Invalid")})
 
         client.run("install --requires=pkg/0.1@ -s os=Windows --build=pkg*", assert_error=True)
-        self.assertIn("pkg/0.1: Cannot build for this configuration: Windows not supported",
-                      client.out)
-        self.assertIn("Windows not supported", client.out)
+        assert "pkg/0.1: Cannot build for this configuration: Windows not supported" in client.out
+        assert "Windows not supported"in client.out
 
         client.run("install --requires=pkg/0.1@ -s os=Windows")
-        self.assertIn(f"pkg/0.1: Main binary package '{missing_id}' missing", client.out)
-        self.assertIn(f"Found compatible package '{package_id}'", client.out)
+        assert f"pkg/0.1: Main binary package '{missing_id}' missing"in client.out
+        assert f"Found compatible package '{package_id}'"in client.out
         client.assert_listed_binary({"pkg/0.1": (package_id, "Cache")})
 
         # --build=missing means "use existing binary if possible", and compatibles are valid binaries
         client.run("install --requires=pkg/0.1@ -s os=Windows --build=missing")
-        self.assertIn(f"pkg/0.1: Main binary package '{missing_id}' missing", client.out)
-        self.assertIn(f"Found compatible package '{package_id}'", client.out)
+        assert f"pkg/0.1: Main binary package '{missing_id}' missing"in client.out
+        assert f"Found compatible package '{package_id}'"in client.out
         client.assert_listed_binary({"pkg/0.1": (package_id, "Cache")})
 
         client.run("graph info --requires=pkg/0.1@ -s os=Windows")
-        self.assertIn(f"pkg/0.1: Main binary package '{missing_id}' missing", client.out)
-        self.assertIn(f"Found compatible package '{package_id}'", client.out)
-        self.assertIn(f"package_id: {package_id}", client.out)
+        assert f"pkg/0.1: Main binary package '{missing_id}' missing"in client.out
+        assert f"Found compatible package '{package_id}'"in client.out
+        assert f"package_id: {package_id}"in client.out
 
         client.run("graph info --requires=pkg/0.1@ -s os=Windows --build=pkg*")
-        self.assertIn("binary: Invalid", client.out)
+        assert "binary: Invalid"in client.out
 
     def test_validate_remove_package_id_create(self):
         client = TestClient()
@@ -177,15 +172,15 @@ class TestValidate(unittest.TestCase):
         client.save({"conanfile.py": conanfile})
 
         client.run("create . --name=pkg --version=0.1 -s os=Linux")
-        self.assertIn("pkg/0.1: Package '{}' created".format(NO_SETTINGS_PACKAGE_ID), client.out)
+        assert "pkg/0.1: Package '{}' created".format(NO_SETTINGS_PACKAGE_ID)in client.out
 
         client.run("create . --name=pkg --version=0.1 -s os=Windows", assert_error=True)
-        self.assertIn("pkg/0.1: Invalid: Windows not supported", client.out)
+        assert "pkg/0.1: Invalid: Windows not supported"in client.out
         client.assert_listed_binary({"pkg/0.1": ("da39a3ee5e6b4b0d3255bfef95601890afd80709",
                                                  "Invalid")})
 
         client.run("graph info --requires=pkg/0.1@ -s os=Windows")
-        self.assertIn("package_id: {}".format(NO_SETTINGS_PACKAGE_ID), client.out)
+        assert "package_id: {}".format(NO_SETTINGS_PACKAGE_ID)in client.out
 
     def test_validate_compatible_also_invalid(self):
         client = TestClient()
@@ -216,8 +211,8 @@ class TestValidate(unittest.TestCase):
         error = client.run("create . --name=pkg --version=0.1 -s os=Windows -s build_type=Release",
                            assert_error=True)
 
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg/0.1: Invalid: Windows not supported", client.out)
+        assert error == ERROR_INVALID_CONFIGURATION
+        assert "pkg/0.1: Invalid: Windows not supported"in client.out
 
         client.run("graph info --requires=pkg/0.1@ -s os=Windows")
         assert "binary: Invalid" in client.out
@@ -243,32 +238,31 @@ class TestValidate(unittest.TestCase):
 
         package_id = "c26ded3c7aa4408e7271e458d65421000e000711"
         client.run("create . --name=pkg --version=0.1 -s os=Linux -s build_type=Release")
-        self.assertIn(f"pkg/0.1: Package '{package_id}' created",
-                      client.out)
+        assert f"pkg/0.1: Package '{package_id}' created" in client.out
         # compatible_packges fallback works
         client.run("install --requires=pkg/0.1@ -s os=Linux -s build_type=Debug")
         client.assert_listed_binary({"pkg/0.1": (package_id, "Cache")})
         # Windows invalid configuration
         error = client.run("create . --name=pkg --version=0.1 -s os=Windows -s build_type=Release",
                            assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg/0.1: Invalid: Windows not supported", client.out)
+        assert error== ERROR_INVALID_CONFIGURATION
+        assert "pkg/0.1: Invalid: Windows not supported"in client.out
 
         error = client.run("install --requires=pkg/0.1@ -s os=Windows -s build_type=Release",
                            assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg/0.1: Invalid: Windows not supported", client.out)
+        assert error== ERROR_INVALID_CONFIGURATION
+        assert "pkg/0.1: Invalid: Windows not supported"in client.out
 
         # Windows missing binary: INVALID
         error = client.run("install --requires=pkg/0.1@ -s os=Windows -s build_type=Debug",
                            assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg/0.1: Invalid: Windows not supported", client.out)
+        assert error== ERROR_INVALID_CONFIGURATION
+        assert "pkg/0.1: Invalid: Windows not supported"in client.out
 
         error = client.run("create . --name=pkg --version=0.1 -s os=Windows -s build_type=Debug",
                            assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg/0.1: Invalid: Windows not supported", client.out)
+        assert error== ERROR_INVALID_CONFIGURATION
+        assert "pkg/0.1: Invalid: Windows not supported"in client.out
 
         # info
         client.run("graph info --requires=pkg/0.1@ -s os=Windows")
@@ -304,8 +298,8 @@ class TestValidate(unittest.TestCase):
 
         client.save({"conanfile.py": GenConanfile().with_requires("pkg2/0.1", "pkg1/0.1")})
         error = client.run("install .", assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg1/0.1: Invalid: Option 2 of 'dep' not supported", client.out)
+        assert error== ERROR_INVALID_CONFIGURATION
+        assert "pkg1/0.1: Invalid: Option 2 of 'dep' not supported"in client.out
 
     def test_validate_requires(self):
         client = TestClient()
@@ -330,15 +324,15 @@ class TestValidate(unittest.TestCase):
                     .with_requirement("pkg1/0.1")
                     .with_requirement("dep/0.2", override=True)})
         error = client.run("install .", assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg1/0.1: Invalid: dep> 0.1 is not supported", client.out)
+        assert error== ERROR_INVALID_CONFIGURATION
+        assert "pkg1/0.1: Invalid: dep> 0.1 is not supported"in client.out
 
         client.save({"conanfile.py": GenConanfile()
                     .with_requirement("pkg1/0.1")
                     .with_requirement("dep/0.2", force=True)})
         error = client.run("install .", assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
-        self.assertIn("pkg1/0.1: Invalid: dep> 0.1 is not supported", client.out)
+        assert error== ERROR_INVALID_CONFIGURATION
+        assert "pkg1/0.1: Invalid: dep> 0.1 is not supported"in client.out
 
     def test_validate_package_id_mode(self):
         client = TestClient()
@@ -358,13 +352,13 @@ class TestValidate(unittest.TestCase):
 
         client.save({"conanfile.py": GenConanfile().with_requires("dep/0.1")})
         error = client.run("create . --name=pkg --version=0.1 -s os=Windows", assert_error=True)
-        self.assertEqual(error, ERROR_INVALID_CONFIGURATION)
+        assert error== ERROR_INVALID_CONFIGURATION
         client.assert_listed_binary({"dep/0.1": ("ebec3dc6d7f6b907b3ada0c3d3cdc83613a2b715",
                                                  "Invalid")})
         client.assert_listed_binary({"pkg/0.1": ("19ad5731bb09f24646c81060bd7730d6cb5b6108",
                                                  "Build")})
-        self.assertIn("ERROR: There are invalid packages:", client.out)
-        self.assertIn("dep/0.1: Invalid: Windows not supported", client.out)
+        assert "ERROR: There are invalid packages:"in client.out
+        assert "dep/0.1: Invalid: Windows not supported"in client.out
 
     def test_validate_export_pkg(self):
         # https://github.com/conan-io/conan/issues/9797
@@ -759,8 +753,7 @@ class TestValidateCppstd:
         assert "Missing prebuilt package for 'app/1.0', 'dep/1.0'" in tc.out
 
 
-
-class TestCompatibleSettingsTarget(unittest.TestCase):
+class TestCompatibleSettingsTarget:
     """ aims to be a very close to real use case of tool being used across different settings_target
     """
     def test_settings_target_in_compatibility_method_within_recipe(self):
@@ -879,9 +872,10 @@ class TestCompatibleSettingsTarget(unittest.TestCase):
             """)
 
         client.save({"conanfile.py": app_conanfile})
-        error = client.run("create . --name=app --version=0.1 -s os=Linux -s:h arch=armv7", assert_error=True)
-        self.assertEqual(error, ERROR_GENERAL)
-        self.assertIn("ERROR: Missing prebuilt package for 'tool/0.1'", client.out)
+        error = client.run("create . --name=app --version=0.1 -s os=Linux -s:h arch=armv7",
+                           assert_error=True)
+        assert error == ERROR_GENERAL
+        assert "ERROR: Missing prebuilt package for 'tool/0.1'"in client.out
 
     def test_no_settings_target_in_recipe_but_in_global_compatibility(self):
         client = TestClient()
@@ -920,8 +914,8 @@ class TestCompatibleSettingsTarget(unittest.TestCase):
 
         client.save({"conanfile.py": app_conanfile})
         error = client.run("create . --name=app --version=0.1 -s os=Linux -s:h arch=armv7", assert_error=True)
-        self.assertEqual(error, ERROR_GENERAL)
-        self.assertIn("ERROR: Missing prebuilt package for 'tool/0.1'", client.out)
+        assert error == ERROR_GENERAL
+        assert "ERROR: Missing prebuilt package for 'tool/0.1'"in client.out
 
     def test_three_packages_with_and_without_settings_target(self):
         client = TestClient()
