@@ -317,7 +317,6 @@ class PyRequiresExtendTest(unittest.TestCase):
                 author = "author@company.com"
                 exports = "*.txt"
                 exports_sources = "*.h"
-                short_paths = True
                 generators = "CMakeToolchain"
             """)
         client.save({"conanfile.py": conanfile,
@@ -334,7 +333,6 @@ class PyRequiresExtendTest(unittest.TestCase):
                 def build(self):
                     self.output.info("Exports sources! %s" % self.exports_sources)
                     self.output.info("HEADER CONTENT!: %s" % load(self, "header.h"))
-                    self.output.info("Short paths! %s" % self.short_paths)
                     self.output.info("License! %s" % self.license)
                     self.output.info("Author! %s" % self.author)
                     assert os.path.exists("conan_toolchain.cmake")
@@ -346,7 +344,6 @@ class PyRequiresExtendTest(unittest.TestCase):
         self.assertIn("pkg/0.1@user/testing: Exports sources! *.h", client.out)
         self.assertIn("pkg/0.1@user/testing: Copied 1 '.txt' file: other.txt", client.out)
         self.assertIn("pkg/0.1@user/testing: Copied 1 '.h' file: header.h", client.out)
-        self.assertIn("pkg/0.1@user/testing: Short paths! True", client.out)
         self.assertIn("pkg/0.1@user/testing: License! MyLicense", client.out)
         self.assertIn("pkg/0.1@user/testing: Author! author@company.com", client.out)
         self.assertIn("pkg/0.1@user/testing: HEADER CONTENT!: pkg new header contents", client.out)
@@ -672,6 +669,54 @@ class PyRequiresExtendTest(unittest.TestCase):
         self.assertIn("mypkg/myversion: Pkg1 build: mypkg:myversion", client.out)
         self.assertIn("mypkg/myversion: Pkg1 package: mypkg:myversion", client.out)
 
+
+    def test_reuse_name_version_override(self):
+        client = TestClient(light=True)
+
+        conanfile = textwrap.dedent("""
+            from conan import ConanFile
+            from conan.tools.files import load
+            import os
+
+            class Source(object):
+                def set_name(self):
+                    self.name = load(self, "name.txt")
+
+                def set_version(self):
+                    self.version = load(self, "version.txt")
+
+            class MyConanfileBase(ConanFile):
+                pass
+            """)
+        client.save({"conanfile.py": conanfile})
+        client.run("export . --name=tool --version=0.1 --user=user --channel=channel")
+        conanfile = textwrap.dedent("""
+            from conan import ConanFile
+            class MyConanfileBase(ConanFile):
+                python_requires = "tool/0.1@user/channel"
+                python_requires_extend = "tool.Source"
+
+                def set_version(self):
+                    super().set_version()
+                    self.version = self.version + "2"
+
+                def source(self):
+                    self.output.info("Pkg1 source: %s:%s" % (self.name, self.version))
+                def build(self):
+                    self.output.info("Pkg1 build: %s:%s" % (self.name, self.version))
+                def package(self):
+                    self.output.info("Pkg1 package: %s:%s" % (self.name, self.version))
+            """)
+        client.save({"conanfile.py": conanfile,
+                     "name.txt": "mypkg",
+                     "version.txt": "myversion"})
+        client.run("export .")
+        self.assertIn("mypkg/myversion2: Exported", client.out)
+        client.run("create .")
+        self.assertIn("mypkg/myversion2: Pkg1 source: mypkg:myversion2", client.out)
+        self.assertIn("mypkg/myversion2: Pkg1 build: mypkg:myversion2", client.out)
+        self.assertIn("mypkg/myversion2: Pkg1 package: mypkg:myversion2", client.out)
+
     def test_reuse_export_sources(self):
         client = TestClient(light=True)
         conanfile = textwrap.dedent("""
@@ -1080,6 +1125,8 @@ class TestTestPackagePythonRequire:
         """
 
         c = TestClient(light=True)
+        c.save({"conanfile.py": GenConanfile("mytool", "0.1")})
+        c.run("create .")
         conanfile = textwrap.dedent("""
             from conan import ConanFile
             def mycommon():
@@ -1100,9 +1147,16 @@ class TestTestPackagePythonRequire:
         c.save({"conanfile.py": conanfile,
                 "test_package/conanfile.py": test})
         c.run("create .")
+        assert "WARN: deprecated: test_package/conanfile.py" not in c.out
         assert "common/0.1 (test package): 42!!!" in c.out
 
         c.run("test test_package common/0.1")
+        assert "WARN: deprecated: test_package/conanfile.py" not in c.out
+        assert "common/0.1 (test package): 42!!!" in c.out
+
+        # https://github.com/conan-io/conan/issues/18224
+        c.save({"myprofile": "[tool_requires]\nmytool/0.1"})
+        c.run("create . -pr=myprofile")
         assert "common/0.1 (test package): 42!!!" in c.out
 
     def test_test_package_python_requires_configs(self):
