@@ -7,7 +7,7 @@ import pytest
 from conan.test.assets.genconanfile import GenConanfile
 from conan.test.utils.test_files import temp_folder
 from conan.test.utils.tools import TestClient
-from conans.util.files import mkdir, save, save_files
+from conan.internal.util.files import mkdir, save, save_files
 
 
 @pytest.fixture(scope="module")
@@ -102,6 +102,13 @@ class TestSearchList:
         revs = listjson["local"]["zlib/1.2.11"]["revisions"]
         assert len(revs) == 1 and "6f5c31bb1219e9393743d1fbf2ee1b52" in revs
 
+    def test_list_revisions_notfound(self, c3i_folder):
+        client = TestClient(light=True)
+        client.run(f"remote add local '{c3i_folder}'")
+        client.run("list potato/1.0#* -r=local")
+        # More like remotes than cache
+        assert "ERROR: Recipe not found: 'potato/1.0'"
+
     def test_list_rrevs(self, c3i_folder):
         client = TestClient(light=True)
         client.run(f"remote add local '{c3i_folder}'")
@@ -349,6 +356,41 @@ class TestErrorsUx:
         c.run("install --requires=zlib/1.2.11#rev1", assert_error=True)
         assert "A specific revision 'zlib/1.2.11#rev1' was requested" in c.out
 
+    def test_no_user_channel(self):
+        # https://github.com/conan-io/conan/issues/18142
+        folder = temp_folder()
+        recipes_folder = os.path.join(folder, "recipes")
+        zlib_config = textwrap.dedent("""
+          versions:
+            "0.1":
+              folder: all
+          """)
+        zlib = GenConanfile("zlib")
+        conandata_yml = textwrap.dedent("""\
+          versions:
+            "0.1":
+          """)
+        save_files(recipes_folder, {"zlib/config.yml": zlib_config,
+                                    "zlib/all/conanfile.py": str(zlib),
+                                    "zlib/all/conandata.yml": conandata_yml})
+        c = TestClient()
+        c.run(f"remote add local '{folder}'")
+        c.run("install --requires=zlib/0.1@myuser/mychannel", assert_error=True)
+        assert "ERROR: Package 'zlib/0.1@myuser/mychannel' not resolved" in c.out
+
+        c = TestClient(default_server_user=True)
+        c.save({"conanfile.py": GenConanfile("zlib", "0.1")})
+        c.run("create . --user=myuser --channel=mychannel")
+        c.run("upload * -r=default -c")
+        c.run(f"remote add local '{folder}' --index=0")
+        c.run("install --requires=zlib/0.1@myuser/mychannel")
+        c.assert_listed_require({"zlib/0.1@myuser/mychannel": "Cache"})
+
+        # Force resolving in remotes
+        c.run("remove * -c")
+        c.run("install --requires=zlib/0.1@myuser/mychannel")
+        c.assert_listed_require({"zlib/0.1@myuser/mychannel": "Downloaded (default)"})
+
 
 class TestPythonRequires:
     @pytest.fixture(scope="class")
