@@ -5,7 +5,7 @@ from conan.tools.files import check_md5, check_sha1, check_sha256
 from conan.errors import ConanException
 from conan.test.utils.mocks import ConanFileMock
 from conan.test.utils.test_files import temp_folder
-from conans.util.files import save
+from conan.internal.util.files import save
 
 
 class HashesTest(unittest.TestCase):
